##  Available Data
The following table provides an overview of data available in the reference catalog and the benefits that you can get by using it. Using base data from the catalog enables you to standardize your portfolio and increase data quality. In addition, by setting fact sheet relations, you can complete your portfolio following modeling best practices.
Type | Base Data | Relations | Detailed Information
---|---|---|---
Business capability | The catalog offers industry-specific, best-practice business capabilities. You can import these into your workspace and customize them to suit your organization’s needs. |  Business capabilities and SAP applications share a many-to-many relation, meaning that each business capability can be linked to multiple SAP applications, and each SAP application can be associated with multiple business capabilities. Applications that best support specific business capabilities are displayed as suggested SAP solutions, which is an explicit relation. Suggested SAP solutions is an optional feature that you can disable if needed. |  [Business Capabilities in the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Import business capabilities from best-practice, industry-specific business capabilities and customize them to suit your organization’s needs.")
Application | The catalog provides reference data for applications, enabling you to enhance fact sheet standardization and increase data quality. This helps users complete fact sheet information with less effort. | When linking applications to catalog items, you can set relations to IT components (as well as relations to providers and tech categories for IT components), which enables you to enrich and automatically complete your portfolio. |  [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.")
IT component |  The catalog provides reference data for IT components, allowing you to enhance fact sheet standardization and improve data quality. This helps users complete fact sheet information with less effort. Additionally, the catalog offers vendor lifecycle information, enabling you to manage technology obsolescence risks effectively. | When linking IT components to catalog items, you can set relations to providers and tech categories, which enables you to enrich and automatically complete your portfolio. |  [IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.")
Tech category | The catalog offers best-practice TBM taxonomies for tech categories. You can import these into your workspace and customize them to suit your company’s categorization needs. | There are no direct relations from tech categories in the catalog. Only relations to tech categories are available. |  [Tech Categories in the Reference Catalog](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Tech categories in the reference catalog enable you to adopt the Technology Business Management \(TBM\) Taxonomy.")


